Create chat
^^^^^^^^^^^

Workflow has those steps:

#. new instance of chat is added to database
#. "invitation code" is generated
#. system message was registered for "chat creator" with "invitation code"
#. "user token" was created